@@ -1,5 +1,5 @@
 # prime/engine/engine-alphabet.rb
-# $Id: engine-alphabet.rb,v 1.3.2.6 2004/01/28 08:34:56 komatsu Exp $
+# $Id: engine-alphabet.rb,v 1.3.2.8 2004/02/06 09:15:09 komatsu Exp $
 #
 # Copyright (C) 2002, 2003, 2004 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -32,13 +32,34 @@ class PrimeEngineAlphabet < PrimeEngine
     else
       results = PrimeWordList.new()
     end
+    if query.pos == '' then
+      query.input.each {|input|
+        numeral = PrimeWord.new(input, input, query.pos, 10000)
+        results.push(numeral)
+      }
+    end
     return results
   end
 
+  def get_pos_data (string)
+    pos_data = {}
+    if string =~ /^[0-9.,+-]+/ then
+      matched_string = $&
+      pos_data.list_push(matched_string, '')
+    end
+    return pos_data
+  end
+
   private
   def search_overall(query)
     results = PrimeWordList.new()
     query.input.each {|string|
+      if PRIME_ENV['typing_method'] == 'tcode' then
+        if string.length == 1 then 
+          results << PrimeWord.new(string.downcase, string,
+                                   "ü", 20000) # T-Code Ǥ 1ʸ
+        end
+      end
       if string == string.upcase and string != string.downcase then
         results << PrimeWord.new(string.downcase, string,
                                  "̤θ", 17000) # ñ(ʸ)
