@@ -1,7 +1,7 @@
 # prime/engine/engine-number.rb
-# $Id: engine-number.rb,v 1.1.2.1 2003/12/13 22:25:27 komatsu Exp $
+# $Id: engine-number.rb,v 1.1.2.3 2004/01/26 06:39:40 komatsu Exp $
 #
-# Copyright (C) 2002 Hiroyuki Komatsu <komatsu@taiyaki.org>
+# Copyright (C) 2002, 2003, 2004 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
 #     This is free software with ABSOLUTELY NO WARRANTY.
 #
@@ -21,21 +21,32 @@ class PrimeEngineNumber < PrimeEngine
     @description = "Number engine"
   end
 
-  private
-  def lookup (input, method = :prefix)
-    results = PrimeResult.new
-
-    calculation = calc(input.original)
-    if calculation then
-      results << PrimeCandidate.new(calculation, calculation, 20000, "ü")
+  def search(query)
+    case query.method
+    when :overall then
+      results = search_overall(query)
+    else
+      results = PrimeWordList.new()
     end
     return results
   end
 
+  private
+  def search_overall(query)
+    results = PrimeWordList.new()
+    query.input.each {|string|
+      calculation = calc(string)
+      if calculation then
+        results << PrimeWord.new(calculation, calculation, "ü", 20000)
+      end
+    }
+    return results
+  end
+
   def calc (string)
     if string =~ /[-+*\/ 0-9()]+=$/ then
       begin
-	return eval(string[0..-2])
+	return eval(string[0..-2]).to_s
       rescue
 	return nil
       end
