@@ -1,5 +1,5 @@
 #### prime-userdict.rb: Library for userdict of PRIME.
-#### $Id: userdict.rb,v 1.1.2.1 2003/12/27 02:49:33 komatsu Exp $
+#### $Id: userdict.rb,v 1.1.2.2 2004/01/28 08:34:57 komatsu Exp $
 ####
 #### Copyright (C) 2003 Hiroyuki Komatsu <komatsu@taiyaki.org>
 ####     All rights reserved.
@@ -136,7 +136,8 @@ class PrimeUserdictUpdate < PrimeUserdict
   end
 
   def check_necessity (input_dict)
-    if File::size(input_dict) == 0 or File::size(input_dict + '-co') == 0 then
+#    if File::size(input_dict) == 0 or File::size(input_dict + '-co') == 0 then
+    if File::size(input_dict) == 0 and File::size(input_dict + '-co') == 0 then
       return false
     else
       return true
@@ -272,9 +273,9 @@ class PrimeUserdictConvert < PrimeUserdict
   def set_pos(pos, prev_pos)
     if pos.nil? or pos.empty? then
       if prev_pos.nil? then
-	pos = "$B8lHx(B"
+	pos = ""
       else
-	pos = "$B3hMQ(B::" + prev_pos
+	pos = "::" + prev_pos
       end
       prev_pos = nil
     else
