@@ -1,5 +1,5 @@
 # prime/prime-japnese.rb: Japanese module for PRIME.
-# $Id: prime-japanese.rb,v 1.1.2.13 2004/01/29 04:20:31 komatsu Exp $
+# $Id: prime-japanese.rb,v 1.1.2.15 2004/02/06 09:15:09 komatsu Exp $
 #
 # Copyright (C) 2004 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -37,7 +37,8 @@ module PrimeJapanese
 	'йԸ', '޹Ը', 'Ը', 'Ը', '(Ԥ)',
 	'', 'ư'],
       '' => ['ʽ֤ˡ', 'ʽ֤ǡ', 'ʽ֤',
-	'ʽ֤Ρ', 'ʽ֤', '֤ϡ']
+	'ʽ֤Ρ', 'ʽ֤', '֤ϡ'],
+      '̾' => ['̾', '()&̾', 'ư&̾'],
     }
 
     @pos_alias_reverse = {}
@@ -53,10 +54,8 @@ module PrimeJapanese
 
     @pos_connection_table = {
       '' => [''],
-      'Ƭ' => ['̾', '()&̾'],
-      '̾'   => ['', 'ư첽', '̾', '()&̾'],
-      '()&̾' =>
-                  ['', 'ư첽', '̾', '()&̾'],
+      'Ƭ' => ['̾'],
+      '̾'   => ['', 'ư첽', '̾'],
 
       '̾&̾'   => ['', 'ư첽'],
       '̾'        => ['', 'ư첽'],
@@ -71,9 +70,9 @@ module PrimeJapanese
       'ƻ::Ϣku' => ['ƻ'],
       'ư::Ϣ' => ['̾', '̾&̾', '̾', '̾'],
       'ư' => ['̾', '̾&̾', '̾', '̾'],
-
       '֤::Ϣde' => ['ư'],
-      '' => ['̾', '̾&̾', '̾', '̾', 'ư', 'ư&̾'],
+      '' => ['̾', '̾&̾', '̾', '̾', 'ư'],
+      'Ϣλ' => ['̾'],
     }
     @pos_connection_cost = {
 #      "Ƭ\t̾" => 0.8,
@@ -82,6 +81,10 @@ module PrimeJapanese
       "\t"  => 0.9,
       "̾&̾\t=" => 0.99,
       "̾\t="      => 0.99,
+      "=\t̾"   => 0.99,
+      "=\t̾"   => 0.99,
+      "=\t̾"   => 0.99,
+      "=ɤ\t̾"   => 0.99,
       "=\t̾" => 0.99,
       "=\t̾" => 0.99,
       "=\t̾" => 0.99,
