@@ -1,5 +1,5 @@
 # prime/prime.rb
-# $Id: prime.rb,v 1.2.2.18 2004/01/29 04:20:31 komatsu Exp $
+# $Id: prime.rb,v 1.2.2.21 2004/02/08 11:58:07 komatsu Exp $
 #
 # Copyright (C) 2002, 2003, 2004 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -32,6 +32,8 @@ class Prime
     @context = nil
 
     initialize_prime_japanese()
+
+    @flag_opened = true
   end
 
   def initialize_rc
@@ -94,9 +96,16 @@ class Prime
   end
 
   def close
-    @engines.command(:close)
+    if @flag_opened then
+      @engines.command(:close)
+      @flag_opened = false
+    end
   end
 
+  def update
+    @engines.command(:update)
+    refresh()
+  end
   def refresh
     initialize_rc()
     PrimeTypeConv::refresh()
@@ -223,7 +232,7 @@ class Prime
 
   public
   def Prime::get_prefix (context, literal)
-    if PRIME_ENV['style_auto_space'] and context then
+    if PRIME_ENV['style_auto_space'] and context and context != "" then
       if (context[-1] > 128 and literal[0] > 128) or
           (literal[0] < ?a and literal[0] > ?z and
              literal[0] < ?A and literal[0] > ?Z) or
@@ -251,7 +260,7 @@ class PrimeQuery
 end
 
 class PrimeWord
-  attr_reader   :pron, :literal, :pos, :index, :label
+  attr_reader   :pron, :literal, :pos, :index
   attr_accessor :category, :annotation, :data, :score, 
       :conjugation, :conjugation_pos, :rest, :prefix
   def initialize(pron, literal, pos, score,
@@ -263,20 +272,31 @@ class PrimeWord
     @category    = category
     @annotation  = annotation
     @data        = data
-    @label       = [pron, literal].join("\t")
-    @index       = [pron, literal, pos].join("\t")
     @conjugation = ""
     @rest        = ""
     @prefix      = ""
+#    @label       = [pron, literal].join("\t")
+    @index       = [pron, literal, pos].join("\t")
   end
 
   def values
     return [@pron, @literal, @pos, @score, @category, @annotation, @data]
   end
 
+  def label ()
+    return (to_text_pron + "\t" + to_text_literal)
+  end
+
+  def to_text_literal
+    return (@prefix + @literal + @conjugation + @rest)
+  end
+  def to_text_pron
+    return (@pron + @conjugation + @rest)
+  end
+
   def to_text
-    return [(@pron    + @conjugation + @rest),
-            (@prefix + @literal + @conjugation + @rest),
+    return [to_text_pron(),
+            to_text_literal(),
             "priority=#{@score}",
             "part=#{@pos}",
             "base=#{@literal}",
@@ -326,14 +346,14 @@ class PrimeWordList < Array
     mark = {}
     merged = PrimeWordList.new
     result.each {|word|
-      if mark[word.label] then
-        word0 = mark[word.label]
+      if mark[word.label()] then
+        word0 = mark[word.label()]
         ## FIXME: Make this merging more intelligence.
         ## FIXME: <komatsu@taiyaki.org> (2004-01-24)
         word0.category   = (word0.category   or word.category)
         word0.annotation = (word0.annotation or word.annotation)
       else
-	mark[word.label] = word
+	mark[word.label()] = word
         word.prefix = Prime::get_prefix(context, word.literal)
 	merged.push(word)
       end
