@@ -1,5 +1,5 @@
 # taiyaki.rb: Ruby Libraries by Hiroyuki Komatsu
-# $Id: taiyaki.rb,v 1.2.2.10 2004/01/28 08:34:56 komatsu Exp $
+# $Id: taiyaki.rb,v 1.2.2.11 2004/02/05 11:39:32 komatsu Exp $
 #
 # Copyright (C) 2002 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -8,6 +8,18 @@
 # You can redistribute it and/or modify it under the terms of 
 # the GNU General Public License version 2.
 
+begin
+  Kernel::require('progressbar')
+rescue LoadError
+  $stderr.puts "WARNING:"
+  $stderr.puts("  The required Ruby library 'progressbar' is not found.")
+  class ProgressBar
+    def initialize (title, estimated_length) end
+    def inc    () end
+    def finish () end
+  end
+end
+
 def require (name, package = nil, url = nil)
   package_name =
          {'progressbar'                => 'progressbar',
